macro_rules! request_option {
($(#[$outer:meta])* $name:ident) => { ... };
}Expand description
Creates a named value type that can be used as a header or in a query string.
Examples
The following macro invocation:
request_option!(Prefix);Turns into a request option useable either as a header or in a query string.